get_destroy_progress

Function get_destroy_progress 

fn get_destroy_progress(player: &Player, block_state: BlockStateId) -> f32
Gets the destroy progress per tick for a block.

This is based on the vanilla formula: 1.0 / (destroy_time * 30.0) for survival with correct tool 1.0 / (destroy_time * 100.0) for survival with wrong tool Instant break for creative mode.